@@ -3,9 +3,9 @@ package Number::Phone::JP::Table::Class1;
 use strict;
 use warnings;
 
-our $VERSION = '0.20151202';
+our $VERSION = '0.20160105';
 
-# Table last modified: 2015-12-02
+# Table last modified: 2016-01-05
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '01'    => '\d+', # KDDI
@@ -21,7 +21,6 @@ our %TEL_TABLE = (
     '039'   => '\d+', # NTT西日本
     '041'   => '\d+', # ソフトバンク
     '046'   => '\d+', # ソフトバンク
-    '050'   => '\d+', # アルテリア・ネットワークス
     '051'   => '\d+', # KDDI
     '052'   => '\d+', # KDDI
     '053'   => '\d+', # KDDI
@@ -40,14 +39,12 @@ our %TEL_TABLE = (
     '073'   => '\d+', # 安子の電話
     '074'   => '\d+', # 安子の電話
     '077'   => '\d+', # KDDI
-    '080'   => '\d+', # Tシステムズ・ジャパン
     '081'   => '\d+', # フュージョンコミュニケーションズ
     '082'   => '\d+', # フュージョンコミュニケーションズ
     '083'   => '\d+', # ソフトバンク
     '084'   => '\d+', # ソフトバンク
     '086'   => '\d+', # 九州通信ネットワーク
     '088'   => '\d+', # ソフトバンク
-    '089'   => '\d+', # Tシステムズ・ジャパン
 );
 
 1;
